sap.ui.jsfragment("sas.fscf.views.fragments.ImportRulesDialog", {

	createContent: function(oController) {
		jQuery.sap.require("sas.hc.m.Dialog");
		jQuery.sap.require("sas.hc.m.MessageDialog");
		jQuery.sap.require("sas.hc.ui.unified.FileUploader");

		var _this = this;
		var oFileUploader;
        var bValidSelection = true;
        var oDialog = new sas.hc.m.Dialog({
        	id: "importRulesDialog",
        	title: sas.fscf.rb.getText('rules.rulesPage.rules.import.importRules.txt'),
    	    content: [
    	              oFileUploader = new sas.hc.ui.unified.FileUploader({
    	                  id: _this.sId + "FileUploader",
    	                  uploadUrl: "rest/businessunits/" + sas.fscf.getCurrentPageView().getBUId() + "/importRules", // URL to submit the form to
    	                  name: "files", 											  // name of the input type=file element within the form
    	                  uploadOnChange: false,                                      // do not immediately upload the file after selection
    	                  sendXHR: true,                                              // use XHR request instead of form submit
    	                  useMultipart: false,										  // send file only and not multipart/form-data
    	                  multiple: false,                                            // upload single file only
    	                  buttonOnly: false,                                          // show both the Input control and the Browse button
    	                  buttonText: sas.fscf.rb.getText("fcm.application.browse.txt"),
    	                  mimeType: ["text/xml"],					  		          // stop the upload process if the selected file is not of this type
    	                  maximumFileSize: 32,                                        // stop the upload process if the selected file exceeds this size (in MB)
    	                  width: "30rem",
    	                  uploadStart: function (oEvent) {
	    	              	  var ajaxHeaders = sas.fscf.getAjaxHeaders();
	    	            	  for (var elem in ajaxHeaders) {
	    	            		  this._aXhr[0].xhr.setRequestHeader(elem, ajaxHeaders[elem]);
	    	           		  }
    	                  },
    	                  filesSelected: function (oEvent) {
    	                      bValidSelection = true;
    	                      var aFilesSelected = oEvent.getParameter("files");
    	                      if (aFilesSelected && aFilesSelected.length > 0) {
    	                    	  sap.ui.getCore().byId(oDialog.getLeftButton()).setEnabled(true);
    	                      }
    	                  },
    	                  fileSizeExceed: function (oEvent) {
    	                      bValidSelection = false;
    	                      // Get the name and size of the file
    	                      var fName = oEvent.getParameter("fileName");
    	                      var fSize = oEvent.getParameter("fileSize");
    	                      var fMaxSize = this.getMaximumFileSize();
    	                      sas.hc.m.MessageDialog.error({text: sas.fscf.rb.getText("fcm.import.fileSizeExceededMessage.fmt.txt", [fName, fSize.toFixed(3), fMaxSize]), title: sas.fscf.rb.getText("fcm.import.fileSizeExceeded.txt")});
	                    	  sap.ui.getCore().byId(oDialog.getLeftButton()).setEnabled(false);
    	                  },
    	                  typeMissmatch: function (oEvent) {
    	                      bValidSelection = false;
    	                      // Get the name and type of the file
    	                      var fName = oEvent.getParameter("fileName");
    	                      var fMimeType = oEvent.getParameter("mimeType");
    	                      var reqMimeType = this.getMimeType();
    	                      sas.hc.m.MessageDialog.error({text: sas.fscf.rb.getText("fcm.import.wrongFileTypeMessage.fmt.txt", [fName, fMimeType, reqMimeType]), title: sas.fscf.rb.getText("fcm.import.wrongFileType.txt")});
	                    	  sap.ui.getCore().byId(oDialog.getLeftButton()).setEnabled(false);
    	                  },
    	                  uploadComplete: function (oEvent) {
    	                      // response from the server
    	                      var sResponse = oEvent.getParameter("responseRaw");
   	                          var isJSON = true;
    	                      // if 'sendXHR=false' then 'responseRaw' is undefined
    	                      if (typeof sResponse === "undefined") {
    	                          sResponse = oEvent.getParameter("response");
    	                      }
    	                      // status code
    	                      var status = oEvent.getParameter("status");
    	                      if (status === 200) {
    	                    	  sas.fscf.getCurrentPageView().getSubView("Rules").updateTable();
    	                    	  oDialog.close();

	    	                      var view = sap.ui.jsfragment({
	    	                          type: sap.ui.core.mvc.ViewType.JS,
	    	                          id: _this.sId + "ImportRulesSuccessDialog",
	    	                          fragmentName: "sas.fscf.views.fragments.ImportRulesSuccessDialog"
	    	                      });
	                              var oResp;
    	                          try {
    	                              oResp = JSON.parse(sResponse);
    	                          } catch(err) {
    	                              isJSON = false;
    	                          }
	    	                      view.setData(oResp);
	    	                      var dialog = view.lazyLoadContent();
	    	                      dialog.open();
    	                      } else {
    	                    	  sap.ui.getCore().byId(oDialog.getLeftButton()).setEnabled(true);
    	          	        	  oDialog.setBusy(false);
    	                          // is it a JSON response?
    	                    	  var oResp;
    	                          try {
    	                              oResp = JSON.parse(sResponse);
    	                          } catch(err) {
    	                              isJSON = false;
    	                          }
    	                          if(isJSON) {
    	                              // that's the HTTP response
    	                              sas.hc.m.MessageDialog.error({text: sas.fscf.rb.getText("fcm.import.errorMessage.fmt.txt", [oResp["message"]]), title: sas.fscf.rb.getText("fcm.import.importError.txt")});
    	                              sap.ui.getCore().byId(oDialog.getLeftButton()).setEnabled(false);
    	                          } else {
    	                              sas.hc.m.MessageDialog.error({text: sas.fscf.rb.getText("fcm.import.errorStatus.fmt.txt", [status]), title: sas.fscf.rb.getText("fcm.import.importError.txt")});
    	                          }
    	                      }
    	                  }
    	              })
    	    ],
    	    leftButton: new sas.hc.m.Button({
    	    	text: sas.fscf.rb.getText('fcm.overview.import.txt'),
    	    	enabled: false,
    	        press: function() {
    	        	this.setEnabled(false);
    	        	oDialog.setBusy(true);
                    oFileUploader.upload();    	        }
    	    }),
    	    rightButton:  new sas.hc.m.Button({
    	    	text: sas.fscf.rb.getText('fcm.application.cancel.txt'),
    	        press: function() {
    	        	oDialog.close();
    	        }
    	    })
        });
        
        oDialog.attachAfterClose(function(oEvent) {
        	this.destroy();
        });

        return oDialog;
    }
    
});
